from pyramid.scaffolds import PyramidTemplate


class PyramidFoundationTemplate(PyramidTemplate):
    _template_dir = 'pyramid_foundation_scaffold'
    summary = 'Pyramid scaffold to extend project with Foundation support'
